==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/fms/kotlin/inputs/PolicyIncludeMapArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.fms.kotlin.inputs

import com.pulumi.aws.fms.inputs.PolicyIncludeMapArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property accounts A list of AWS Organization member Accounts that you want to include for this AWS FMS Policy.
 * @property orgunits A list of IDs of the AWS Organizational Units that you want to include for this AWS FMS Policy. Specifying an OU is the equivalent of specifying all accounts in the OU and in any of its child OUs, including any child OUs and accounts that are added at a later time.
 * You can specify inclusions or exclusions, but not both. If you specify an `include_map`, AWS Firewall Manager applies the policy to all accounts specified by the `include_map`, and does not evaluate any `exclude_map` specifications. If you do not specify an `include_map`, then Firewall Manager applies the policy to all accounts except for those specified by the `exclude_map`.
 */
public data class PolicyIncludeMapArgs(
    public val accounts: Output<List<String>>? = null,
    public val orgunits: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.aws.fms.inputs.PolicyIncludeMapArgs> {
    override fun toJava(): com.pulumi.aws.fms.inputs.PolicyIncludeMapArgs =
        com.pulumi.aws.fms.inputs.PolicyIncludeMapArgs.builder()
            .accounts(accounts?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .orgunits(orgunits?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [PolicyIncludeMapArgs].
 */
@PulumiTagMarker
public class PolicyIncludeMapArgsBuilder internal constructor() {
    private var accounts: Output<List<String>>? = null

    private var orgunits: Output<List<String>>? = null

    /**
     * @param value A list of AWS Organization member Accounts that you want to include for this AWS FMS Policy.
     */
    @JvmName("ppkxbdjyldujehhd")
    public suspend fun accounts(`value`: Output<List<String>>) {
        this.accounts = value
    }

    @JvmName("vqyhcuywwbxkisdq")
    public suspend fun accounts(vararg values: Output<String>) {
        this.accounts = Output.all(values.asList())
    }

    /**
     * @param values A list of AWS Organization member Accounts that you want to include for this AWS FMS Policy.
     */
    @JvmName("pupcwfckyooyyrjf")
    public suspend fun accounts(values: List<Output<String>>) {
        this.accounts = Output.all(values)
    }

    /**
     * @param value A list of IDs of the AWS Organizational Units that you want to include for this AWS FMS Policy. Specifying an OU is the equivalent of specifying all accounts in the OU and in any of its child OUs, including any child OUs and accounts that are added at a later time.
     * You can specify inclusions or exclusions, but not both. If you specify an `include_map`, AWS Firewall Manager applies the policy to all accounts specified by the `include_map`, and does not evaluate any `exclude_map` specifications. If you do not specify an `include_map`, then Firewall Manager applies the policy to all accounts except for those specified by the `exclude_map`.
     */
    @JvmName("kwufmgmrnoafoqbw")
    public suspend fun orgunits(`value`: Output<List<String>>) {
        this.orgunits = value
    }

    @JvmName("nklsiomjxlqxrqfy")
    public suspend fun orgunits(vararg values: Output<String>) {
        this.orgunits = Output.all(values.asList())
    }

    /**
     * @param values A list of IDs of the AWS Organizational Units that you want to include for this AWS FMS Policy. Specifying an OU is the equivalent of specifying all accounts in the OU and in any of its child OUs, including any child OUs and accounts that are added at a later time.
     * You can specify inclusions or exclusions, but not both. If you specify an `include_map`, AWS Firewall Manager applies the policy to all accounts specified by the `include_map`, and does not evaluate any `exclude_map` specifications. If you do not specify an `include_map`, then Firewall Manager applies the policy to all accounts except for those specified by the `exclude_map`.
     */
    @JvmName("iusvybvxckmxtwsm")
    public suspend fun orgunits(values: List<Output<String>>) {
        this.orgunits = Output.all(values)
    }

    /**
     * @param value A list of AWS Organization member Accounts that you want to include for this AWS FMS Policy.
     */
    @JvmName("xfetpegbkasstlft")
    public suspend fun accounts(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.accounts = mapped
    }

    /**
     * @param values A list of AWS Organization member Accounts that you want to include for this AWS FMS Policy.
     */
    @JvmName("cdvnvroratvwlqfk")
    public suspend fun accounts(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.accounts = mapped
    }

    /**
     * @param value A list of IDs of the AWS Organizational Units that you want to include for this AWS FMS Policy. Specifying an OU is the equivalent of specifying all accounts in the OU and in any of its child OUs, including any child OUs and accounts that are added at a later time.
     * You can specify inclusions or exclusions, but not both. If you specify an `include_map`, AWS Firewall Manager applies the policy to all accounts specified by the `include_map`, and does not evaluate any `exclude_map` specifications. If you do not specify an `include_map`, then Firewall Manager applies the policy to all accounts except for those specified by the `exclude_map`.
     */
    @JvmName("nhkpesjejkfwuton")
    public suspend fun orgunits(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.orgunits = mapped
    }

    /**
     * @param values A list of IDs of the AWS Organizational Units that you want to include for this AWS FMS Policy. Specifying an OU is the equivalent of specifying all accounts in the OU and in any of its child OUs, including any child OUs and accounts that are added at a later time.
     * You can specify inclusions or exclusions, but not both. If you specify an `include_map`, AWS Firewall Manager applies the policy to all accounts specified by the `include_map`, and does not evaluate any `exclude_map` specifications. If you do not specify an `include_map`, then Firewall Manager applies the policy to all accounts except for those specified by the `exclude_map`.
     */
    @JvmName("grvrsqoeeyerfome")
    public suspend fun orgunits(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.orgunits = mapped
    }

    internal fun build(): PolicyIncludeMapArgs = PolicyIncludeMapArgs(
        accounts = accounts,
        orgunits = orgunits,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/fms/kotlin/inputs/PolicyIncludeMapArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.fms.kotlin.inputs

import com.pulumi.aws.fms.inputs.PolicyIncludeMapArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property accounts A list of AWS Organization member Accounts that you want to include for this AWS FMS Policy.
 * @property orgunits A list of IDs of the AWS Organizational Units that you want to include for this AWS FMS Policy. Specifying an OU is the equivalent of specifying all accounts in the OU and in any of its child OUs, including any child OUs and accounts that are added at a later time.
 * You can specify inclusions or exclusions, but not both. If you specify an `include_map`, AWS Firewall Manager applies the policy to all accounts specified by the `include_map`, and does not evaluate any `exclude_map` specifications. If you do not specify an `include_map`, then Firewall Manager applies the policy to all accounts except for those specified by the `exclude_map`.
 */
public data class PolicyIncludeMapArgs(
    public val accounts: Output<List<String>>? = null,
    public val orgunits: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.aws.fms.inputs.PolicyIncludeMapArgs> {
    override fun toJava(): com.pulumi.aws.fms.inputs.PolicyIncludeMapArgs =
        com.pulumi.aws.fms.inputs.PolicyIncludeMapArgs.builder()
            .accounts(accounts?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .orgunits(orgunits?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [PolicyIncludeMapArgs].
 */
@PulumiTagMarker
public class PolicyIncludeMapArgsBuilder internal constructor() {
    private var accounts: Output<List<String>>? = null

    private var orgunits: Output<List<String>>? = null

    /**
     * @param value A list of AWS Organization member Accounts that you want to include for this AWS FMS Policy.
     */
    @JvmName("xogoqninfhnitotr")
    public suspend fun accounts(`value`: Output<List<String>>) {
        this.accounts = value
    }

    @JvmName("gvertoouhkuccibj")
    public suspend fun accounts(vararg values: Output<String>) {
        this.accounts = Output.all(values.asList())
    }

    /**
     * @param values A list of AWS Organization member Accounts that you want to include for this AWS FMS Policy.
     */
    @JvmName("aixohwwnglrisrvj")
    public suspend fun accounts(values: List<Output<String>>) {
        this.accounts = Output.all(values)
    }

    /**
     * @param value A list of IDs of the AWS Organizational Units that you want to include for this AWS FMS Policy. Specifying an OU is the equivalent of specifying all accounts in the OU and in any of its child OUs, including any child OUs and accounts that are added at a later time.
     * You can specify inclusions or exclusions, but not both. If you specify an `include_map`, AWS Firewall Manager applies the policy to all accounts specified by the `include_map`, and does not evaluate any `exclude_map` specifications. If you do not specify an `include_map`, then Firewall Manager applies the policy to all accounts except for those specified by the `exclude_map`.
     */
    @JvmName("qfesvjxiqamhmeij")
    public suspend fun orgunits(`value`: Output<List<String>>) {
        this.orgunits = value
    }

    @JvmName("bnxaskbivtchkrxj")
    public suspend fun orgunits(vararg values: Output<String>) {
        this.orgunits = Output.all(values.asList())
    }

    /**
     * @param values A list of IDs of the AWS Organizational Units that you want to include for this AWS FMS Policy. Specifying an OU is the equivalent of specifying all accounts in the OU and in any of its child OUs, including any child OUs and accounts that are added at a later time.
     * You can specify inclusions or exclusions, but not both. If you specify an `include_map`, AWS Firewall Manager applies the policy to all accounts specified by the `include_map`, and does not evaluate any `exclude_map` specifications. If you do not specify an `include_map`, then Firewall Manager applies the policy to all accounts except for those specified by the `exclude_map`.
     */
    @JvmName("jyheumsyagqmilhc")
    public suspend fun orgunits(values: List<Output<String>>) {
        this.orgunits = Output.all(values)
    }

    /**
     * @param value A list of AWS Organization member Accounts that you want to include for this AWS FMS Policy.
     */
    @JvmName("jyicpsfxwdfdspey")
    public suspend fun accounts(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.accounts = mapped
    }

    /**
     * @param values A list of AWS Organization member Accounts that you want to include for this AWS FMS Policy.
     */
    @JvmName("qtcgoirqkgyxvuqj")
    public suspend fun accounts(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.accounts = mapped
    }

    /**
     * @param value A list of IDs of the AWS Organizational Units that you want to include for this AWS FMS Policy. Specifying an OU is the equivalent of specifying all accounts in the OU and in any of its child OUs, including any child OUs and accounts that are added at a later time.
     * You can specify inclusions or exclusions, but not both. If you specify an `include_map`, AWS Firewall Manager applies the policy to all accounts specified by the `include_map`, and does not evaluate any `exclude_map` specifications. If you do not specify an `include_map`, then Firewall Manager applies the policy to all accounts except for those specified by the `exclude_map`.
     */
    @JvmName("aishyvlyjuhyjeef")
    public suspend fun orgunits(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.orgunits = mapped
    }

    /**
     * @param values A list of IDs of the AWS Organizational Units that you want to include for this AWS FMS Policy. Specifying an OU is the equivalent of specifying all accounts in the OU and in any of its child OUs, including any child OUs and accounts that are added at a later time.
     * You can specify inclusions or exclusions, but not both. If you specify an `include_map`, AWS Firewall Manager applies the policy to all accounts specified by the `include_map`, and does not evaluate any `exclude_map` specifications. If you do not specify an `include_map`, then Firewall Manager applies the policy to all accounts except for those specified by the `exclude_map`.
     */
    @JvmName("owhlvjdwixnqjvug")
    public suspend fun orgunits(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.orgunits = mapped
    }

    internal fun build(): PolicyIncludeMapArgs = PolicyIncludeMapArgs(
        accounts = accounts,
        orgunits = orgunits,
    )
}
